
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xaw3d/Repeater.h>
#include <X11/xv/xvCore.h>
#include <X11/xv/xvFont.h>
#include <X11/xv/xvBasicBitmap.h>
#include <X11/xv/xvRepeater.h>

// -----------------------------------------------------------------

xvRepeater::xvRepeater()
{
	alloc=FALSE;
}

// -----------------------------------------------------------------

xvRepeater::xvRepeater(String name, xvCore & parent, XtCallbackProc callback,
	String client, XtCallbackProc startcall, XtCallbackProc stopcall)
{
	init(name, parent, callback, client, startcall, stopcall);
}

// =================================================================

xvRepeater::~xvRepeater()
{
	if (alloc) XtDestroyWidget(w);
}

// -----------------------------------------------------------------

void xvRepeater::init(char *name, xvCore & parent, XtCallbackProc callback,
	String client, XtCallbackProc startcall, XtCallbackProc stopcall)
{
	w=XtVaCreateManagedWidget(name, repeaterWidgetClass, parent.ID(), 
		"flash", TRUE, 
		NULL);
          
	XtAddCallback(w, XtNcallback, callback, (XtPointer) client);
	XtAddCallback(w, XtNstartCallback, startcall, (XtPointer) client);
	XtAddCallback(w, XtNstopCallback, stopcall, (XtPointer) client);
	alloc=TRUE;

	bfont.init(w, NULL);
	bmap.init(NULL, w);
}

// ------------------------------------------

void xvRepeater::ChangeFont(String fontname)
{
	if (fontname != NULL) {
		bfont.FLoadFont(fontname);
		XtVaSetValues(w, XtNfont, (XtArgVal) bfont.FontRef(), NULL);
	}
}

// -----------------------------------------------------------------

int xvRepeater::ChangeBitmap(String name, int pixtype, int position)
{
	int err;

	if ((err=bmap.ReadFile(name, pixtype)) == 0)
		if (position==XVCENTREBITMAP)
			XtVaSetValues(w, XtNbitmap, (XtArgVal) bmap.GetPixmap(), NULL);
		else
			XtVaSetValues(w, XtNleftBitmap, (XtArgVal) bmap.GetPixmap(), NULL);

	return(err);
}

// -----------------------------------------------------------------